@@ -45,7 +45,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         # was imported, also to cover requirement from
         # OvnProviderHelper and intra references modules
         ovn_conf.register_opts()
-        self._ovn_helper = ovn_helper.OvnProviderHelper()
+        self._ovn_helper = ovn_helper.OvnProviderHelper(notifier=False)
 
     def __del__(self):
         self._ovn_helper.shutdown()
@@ -68,6 +68,16 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                 user_fault_string=msg,
                 operator_fault_string=msg)
 
+    def _check_for_supported_session_persistence(self, session):
+        if (session and
+                session.get("type") not in
+                ovn_const.OVN_NATIVE_SESSION_PERSISTENCE):
+            msg = _('OVN provider does not support %s session persistence. '
+                    'Only SOURCE_IP type is supported.') % session.type
+            raise driver_exceptions.UnsupportedOptionError(
+                user_fault_string=msg,
+                operator_fault_string=msg)
+
     def _check_for_allowed_cidrs(self, allowed_cidrs):
         # TODO(haleyb): add support for this
         if isinstance(allowed_cidrs, o_datamodels.UnsetType):
@@ -100,7 +110,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                 self.pool_create(pool)
                 for member in pool.members:
                     if not member.subnet_id:
-                        member.subnet_id = loadbalancer.vip_network_id
+                        member.subnet_id = loadbalancer.vip_subnet_id
                     self.member_create(member)
 
     def loadbalancer_delete(self, loadbalancer, cascade=False):
@@ -140,6 +150,11 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                         'admin_state_up': admin_state_up}
         request = {'type': ovn_const.REQ_TYPE_POOL_CREATE,
                    'info': request_info}
+        if not isinstance(
+                pool.session_persistence, o_datamodels.UnsetType):
+            self._check_for_supported_session_persistence(
+                pool.session_persistence)
+            request['info']['session_persistence'] = pool.session_persistence
         self._ovn_helper.add_request(request)
         if pool.healthmonitor is not None and not isinstance(
                 pool.healthmonitor, o_datamodels.UnsetType):
@@ -170,6 +185,12 @@ class OvnProviderDriver(driver_base.ProviderDriver):
 
         if not isinstance(new_pool.admin_state_up, o_datamodels.UnsetType):
             request_info['admin_state_up'] = new_pool.admin_state_up
+        if not isinstance(
+                new_pool.session_persistence, o_datamodels.UnsetType):
+            self._check_for_supported_session_persistence(
+                new_pool.session_persistence)
+            request_info['session_persistence'] = (
+                new_pool.session_persistence)
         request = {'type': ovn_const.REQ_TYPE_POOL_UPDATE,
                    'info': request_info}
         self._ovn_helper.add_request(request)
@@ -352,6 +373,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         existing_members = pool.split(',') if pool else []
         members_to_delete = copy.copy(existing_members)
         pool_subnet_id = None
+        pool_subnet_cidr = None
         for member in members:
             # NOTE(froyo): in order to keep sync with Octavia DB, we raise
             # not supporting exceptions as soon as posible, considering the
@@ -456,15 +478,18 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         # TODO(gthiemonge): implement additional_vip_dicts
         try:
             port = self._ovn_helper.create_vip_port(
-                project_id, lb_id, vip_dict)['port']
+                project_id, lb_id, vip_dict)
             vip_dict[constants.VIP_PORT_ID] = port['id']
             vip_dict[constants.VIP_ADDRESS] = (
                 port['fixed_ips'][0]['ip_address'])
         except Exception as e:
             kwargs = {}
-            if hasattr(e, 'message'):
-                kwargs = {'user_fault_string': e.message,
-                          'operator_fault_string': e.message}
+            for attr in ('details', 'message'):
+                if hasattr(e, attr):
+                    value = getattr(e, attr)
+                    kwargs = {'user_fault_string': value,
+                              'operator_fault_string': value}
+                    break
             raise driver_exceptions.DriverError(
                 **kwargs)
         return vip_dict, []
