@@ -60,38 +60,43 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
         self.fake_neutron_client = mock.MagicMock()
         clients.get_neutron_client = mock.MagicMock()
         clients.get_neutron_client.return_value = self.fake_neutron_client
-        self.fake_neutron_client.show_network = self._mock_show_network
-        self.fake_neutron_client.show_subnet = self._mock_show_subnet
-        self.fake_neutron_client.list_ports = self._mock_list_ports
-        self.fake_neutron_client.show_port = self._mock_show_port
+        self.fake_neutron_client.get_network = self._mock_get_network
+        self.fake_neutron_client.get_subnet = self._mock_get_subnet
+        self.fake_neutron_client.ports = self._mock_ports
+        self.fake_neutron_client.get_port = self._mock_get_port
         self.fake_neutron_client.delete_port.return_value = True
         self._local_net_cache = {}
         self._local_cidr_cache = {}
         self._local_port_cache = {'ports': []}
         self.core_plugin = directory.get_plugin()
 
-    def _mock_show_network(self, network_id):
-        network = {}
-        network['id'] = network_id
-        network['provider:physical_network'] = None
-        return {'network': network}
+    def _port_dict_to_mock(self, port_dict):
+        port = mock.Mock(**port_dict)
+        return port
 
-    def _mock_show_subnet(self, subnet_id):
-        subnet = {}
-        subnet['network_id'] = self._local_net_cache[subnet_id]
-        subnet['cidr'] = self._local_cidr_cache[subnet_id]
-        return {'subnet': subnet}
+    def _mock_get_network(self, network_id):
+        network = mock.Mock()
+        network.id = network_id
+        network.provider_physical_network = None
+        return network
 
-    def _mock_list_ports(self, **kwargs):
-        return self._local_port_cache
+    def _mock_get_subnet(self, subnet_id):
+        subnet = mock.Mock()
+        subnet.network_id = self._local_net_cache[subnet_id]
+        subnet.cidr = self._local_cidr_cache[subnet_id]
+        subnet.gateway_ip = None
+        return subnet
 
-    def _mock_show_port(self, port_id):
+    def _mock_ports(self, **kwargs):
+        return self._local_port_cache['ports']
+
+    def _mock_get_port(self, port_id):
         for port in self._local_port_cache['ports']:
-            if port['id'] == port_id:
-                return {'port': port}
+            if port.id == port_id:
+                return port
 
     def _create_provider_network(self):
-        e1 = self._make_network(self.fmt, 'e1', True,
+        e1 = self._make_network(self.fmt, 'e1', True, True,
                                 arg_list=('router:external',
                                           'provider:network_type',
                                           'provider:physical_network'),
@@ -289,7 +294,8 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
         if router_id:
             self.l3_plugin.add_router_interface(
                 self.context, router_id, {'subnet_id': subnet['id']})
-        self._local_port_cache['ports'].append(port['port'])
+        self._local_port_cache['ports'].append(
+            self._port_dict_to_mock(port['port']))
         vip_port_address = port['port']['fixed_ips'][0]['ip_address']
         return (n1['network']['id'], subnet['id'], vip_port_address,
                 port['port']['id'])
@@ -336,11 +342,12 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
                         # Withing this status update check if all values of
                         # expected keys match.
                         for k, v in expected_status.items():
-                            val_check.append(
-                                sorted(expected_status[k],
-                                       key=lambda x: x['id']) ==
-                                sorted(updated_status[k],
-                                       key=lambda x: x['id']))
+                            ex = sorted(expected_status[k],
+                                        key=lambda x: x['id'])
+                            ox = sorted(updated_status[k],
+                                        key=lambda x: x['id'])
+                            val_check.append(all(item in ox for item in ex))
+
                         if False in val_check:
                             # At least one value don't match.
                             continue
@@ -627,13 +634,13 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
                 if m.subnet_id:
                     # Need to get the network_id.
                     for port in self._local_port_cache['ports']:
-                        for fixed_ip in port['fixed_ips']:
+                        for fixed_ip in port.fixed_ips:
                             if fixed_ip['subnet_id'] == m.subnet_id:
                                 ex = external_ids[
                                     ovn_const.LB_EXT_IDS_LS_REFS_KEY]
                                 act = ex.get(
-                                    'neutron-%s' % port['network_id'], 0)
-                                ex['neutron-%s' % port['network_id']] = act + 1
+                                    'neutron-%s' % port.network_id, 0)
+                                ex['neutron-%s' % port.network_id] = act + 1
                                 break
                 if p.healthmonitor:
                     member_status[m.member_id] = o_constants.ONLINE
@@ -787,7 +794,8 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
                               "provisioning_status": o_constants.DELETED}],
                  'loadbalancers': [{
                      "id": p.loadbalancer_id,
-                     "provisioning_status": o_constants.ACTIVE}],
+                     "provisioning_status": o_constants.ACTIVE,
+                     'operating_status': o_constants.ONLINE}],
                  'listeners': []})
             self._update_ls_refs(
                 lb_data, self._local_net_cache[m.subnet_id], add_ref=False)
@@ -855,7 +863,8 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
         self._update_ls_refs(lb_data, network_id)
         pool_listeners = self._get_pool_listeners(lb_data, pool_id)
         expected_listener_status = [
-            {'id': listener.listener_id, 'provisioning_status': 'ACTIVE'}
+            {'id': listener.listener_id, 'provisioning_status': 'ACTIVE',
+             'operating_status': o_constants.ONLINE}
             for listener in pool_listeners]
 
         expected_status = {
@@ -864,7 +873,8 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
                          "provisioning_status": "ACTIVE",
                          "operating_status": o_constants.NO_MONITOR}],
             'loadbalancers': [{'id': pool.loadbalancer_id,
-                               'provisioning_status': 'ACTIVE'}],
+                               'provisioning_status': 'ACTIVE',
+                               'operating_status': o_constants.ONLINE}],
             'listeners': expected_listener_status
         }
         self._wait_for_status_and_validate(lb_data, [expected_status])
@@ -892,11 +902,13 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
         self.ovn_driver.member_update(old_member, member)
         expected_status = {
             'pools': [{'id': pool.pool_id,
-                       'provisioning_status': 'ACTIVE'}],
+                       'provisioning_status': 'ACTIVE',
+                       'operating_status': o_constants.ONLINE}],
             'members': [{"id": member.member_id,
                          'provisioning_status': 'ACTIVE'}],
             'loadbalancers': [{'id': pool.loadbalancer_id,
-                               'provisioning_status': 'ACTIVE'}],
+                               'provisioning_status': 'ACTIVE',
+                               'operating_status': o_constants.ONLINE}],
             'listeners': []
         }
         if getattr(member, 'admin_state_up', None):
@@ -920,7 +932,8 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
                               'provisioning_status': 'ACTIVE',
                               'operating_status': 'ONLINE'}],
                  'loadbalancers': [{'id': pool.loadbalancer_id,
-                                   'provisioning_status': 'ACTIVE'}],
+                                    'provisioning_status': 'ACTIVE',
+                                    'operating_status': o_constants.ONLINE}],
                  'listeners': []})
         for m in pool.members:
             found = False
@@ -968,7 +981,8 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
             'members': [{"id": member.member_id,
                          "provisioning_status": "DELETED"}],
             'loadbalancers': [{"id": pool.loadbalancer_id,
-                               "provisioning_status": "ACTIVE"}],
+                               'provisioning_status': 'ACTIVE',
+                               'operating_status': o_constants.ONLINE}],
             'listeners': []}
 
         self._update_ls_refs(lb_data, network_id, add_ref=False)
@@ -986,6 +1000,10 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
                                      max_retries, hm_type)
         pool.healthmonitor = m_hm
 
+        self.ovn_driver._ovn_helper._update_hm_member = mock.MagicMock()
+        self.ovn_driver._ovn_helper._update_hm_member.side_effect = [
+            o_constants.ONLINE, o_constants.ONLINE]
+
         self.ovn_driver.health_monitor_create(m_hm)
         pool_listeners = self._get_pool_listeners(lb_data, pool_id)
         expected_listener_status = [
@@ -1005,7 +1023,8 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
             'pools': [pool_status],
             'members': expected_member_status,
             'loadbalancers': [{'id': pool.loadbalancer_id,
-                               'provisioning_status': o_constants.ACTIVE}],
+                               'provisioning_status': o_constants.ACTIVE,
+                               'operating_status': o_constants.ONLINE}],
             'listeners': expected_listener_status,
             'healthmonitors': [expected_hm_status]
         }
