@@ -89,7 +89,7 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
             members=[self.ref_member],
             pool_id=self.pool_id,
             protocol='TCP',
-            session_persistence={'type': 'fix'})
+            session_persistence={'type': 'SOURCE_IP'})
         self.ref_pool = data_models.Pool(
             admin_state_up=True,
             description='pool',
@@ -100,7 +100,7 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
             members=[self.ref_member],
             pool_id=self.pool_id,
             protocol='TCP',
-            session_persistence={'type': 'fix'})
+            session_persistence={'type': 'SOURCE_IP'})
         self.ref_http_pool = data_models.Pool(
             admin_state_up=True,
             description='pool',
@@ -171,7 +171,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
             name='favorite_lb0',
             project_id=self.project_id,
             vip_address=self.vip_address,
-            vip_network_id=self.vip_network_id)
+            vip_network_id=self.vip_network_id,
+            vip_subnet_id=self.vip_subnet_id)
         self.ref_lb0 = data_models.LoadBalancer(
             admin_state_up=False,
             listeners=[self.ref_listener],
@@ -689,7 +690,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
             'listener_id': self.ref_pool.listener_id,
             'protocol': self.ref_pool.protocol,
             'lb_algorithm': constants.LB_ALGORITHM_SOURCE_IP_PORT,
-            'admin_state_up': self.ref_pool.admin_state_up}
+            'admin_state_up': self.ref_pool.admin_state_up,
+            'session_persistence': {'type': 'SOURCE_IP'}}
         info_member = {
             'id': self.ref_member.member_id,
             'address': self.ref_member.address,
@@ -758,19 +760,20 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
             'listener_id': self.ref_pool.listener_id,
             'protocol': self.ref_pool.protocol,
             'lb_algorithm': constants.LB_ALGORITHM_SOURCE_IP_PORT,
-            'admin_state_up': self.ref_pool.admin_state_up}
+            'admin_state_up': self.ref_pool.admin_state_up,
+            'session_persistence': {'type': 'SOURCE_IP'}}
         info_member = {
             'id': self.ref_member.member_id,
             'address': self.ref_member.address,
             'protocol_port': self.ref_member.protocol_port,
             'pool_id': self.ref_member.pool_id,
-            'subnet_id': self.ref_lb_fully_populated.vip_network_id,
+            'subnet_id': self.ref_lb_fully_populated.vip_subnet_id,
             'admin_state_up': self.ref_member.admin_state_up}
         info_dvr = {
             'id': self.ref_member.member_id,
             'address': self.ref_member.address,
             'pool_id': self.ref_member.pool_id,
-            'subnet_id': self.ref_lb_fully_populated.vip_network_id,
+            'subnet_id': self.ref_lb_fully_populated.vip_subnet_id,
             'action': ovn_const.REQ_INFO_MEMBER_ADDED}
         expected_lb_dict = {
             'type': ovn_const.REQ_TYPE_LB_CREATE,
@@ -866,7 +869,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'listener_id': self.ref_pool.listener_id,
                 'protocol': self.ref_pool.protocol,
                 'lb_algorithm': constants.LB_ALGORITHM_SOURCE_IP_PORT,
-                'admin_state_up': self.ref_pool.admin_state_up}
+                'admin_state_up': self.ref_pool.admin_state_up,
+                'session_persistence': {'type': 'SOURCE_IP'}}
         expected_dict = {'type': ovn_const.REQ_TYPE_POOL_CREATE,
                          'info': info}
         self.driver.pool_create(self.ref_pool)
@@ -879,7 +883,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'listener_id': self.ref_pool.listener_id,
                 'protocol': self.ref_pool.protocol,
                 'lb_algorithm': constants.LB_ALGORITHM_SOURCE_IP_PORT,
-                'admin_state_up': self.ref_pool.admin_state_up}
+                'admin_state_up': self.ref_pool.admin_state_up,
+                'session_persistence': {'type': 'SOURCE_IP'}}
         info_hm = {'id': self.ref_health_monitor.healthmonitor_id,
                    'pool_id': self.ref_health_monitor.pool_id,
                    'type': self.ref_health_monitor.type,
@@ -905,7 +910,21 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'protocol': self.ref_pool.protocol,
                 'lb_algorithm': constants.LB_ALGORITHM_SOURCE_IP_PORT,
                 'listener_id': self.ref_pool.listener_id,
-                'admin_state_up': True}
+                'admin_state_up': True,
+                'session_persistence': {'type': 'SOURCE_IP'}}
+        expected_dict = {'type': ovn_const.REQ_TYPE_POOL_CREATE,
+                         'info': info}
+        self.driver.pool_create(self.ref_pool)
+        self.mock_add_request.assert_called_once_with(expected_dict)
+
+    def test_pool_create_unset_session_persistence(self):
+        self.ref_pool.session_persistence = data_models.UnsetType()
+        info = {'id': self.ref_pool.pool_id,
+                'loadbalancer_id': self.ref_pool.loadbalancer_id,
+                'protocol': self.ref_pool.protocol,
+                'lb_algorithm': constants.LB_ALGORITHM_SOURCE_IP_PORT,
+                'listener_id': self.ref_pool.listener_id,
+                'admin_state_up': self.ref_pool.admin_state_up}
         expected_dict = {'type': ovn_const.REQ_TYPE_POOL_CREATE,
                          'info': info}
         self.driver.pool_create(self.ref_pool)
@@ -956,7 +975,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         info = {'id': self.ref_update_pool.pool_id,
                 'loadbalancer_id': self.ref_update_pool.loadbalancer_id,
                 'protocol': self.ref_pool.protocol,
-                'admin_state_up': self.ref_update_pool.admin_state_up}
+                'admin_state_up': self.ref_update_pool.admin_state_up,
+                'session_persistence': {'type': 'SOURCE_IP'}}
         expected_dict = {'type': ovn_const.REQ_TYPE_POOL_UPDATE,
                          'info': info}
         self.driver.pool_update(self.ref_pool, self.ref_update_pool)
@@ -967,7 +987,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         info = {'id': self.ref_update_pool.pool_id,
                 'loadbalancer_id': self.ref_update_pool.loadbalancer_id,
                 'protocol': self.ref_pool.protocol,
-                'admin_state_up': self.ref_update_pool.admin_state_up}
+                'admin_state_up': self.ref_update_pool.admin_state_up,
+                'session_persistence': {'type': 'SOURCE_IP'}}
         expected_dict = {'type': ovn_const.REQ_TYPE_POOL_UPDATE,
                          'info': info}
         self.driver.pool_update(self.ref_pool, self.ref_update_pool)
@@ -978,7 +999,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         info = {'id': self.ref_update_pool.pool_id,
                 'loadbalancer_id': self.ref_update_pool.loadbalancer_id,
                 'protocol': self.ref_pool.protocol,
-                'admin_state_up': self.ref_update_pool.admin_state_up}
+                'admin_state_up': self.ref_update_pool.admin_state_up,
+                'session_persistence': {'type': 'SOURCE_IP'}}
         expected_dict = {'type': ovn_const.REQ_TYPE_POOL_UPDATE,
                          'info': info}
         self.driver.pool_update(self.ref_pool, self.ref_update_pool)
@@ -988,7 +1010,19 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.ref_update_pool.admin_state_up = data_models.UnsetType()
         info = {'id': self.ref_update_pool.pool_id,
                 'loadbalancer_id': self.ref_update_pool.loadbalancer_id,
-                'protocol': self.ref_pool.protocol}
+                'protocol': self.ref_pool.protocol,
+                'session_persistence': {'type': 'SOURCE_IP'}}
+        expected_dict = {'type': ovn_const.REQ_TYPE_POOL_UPDATE,
+                         'info': info}
+        self.driver.pool_update(self.ref_pool, self.ref_update_pool)
+        self.mock_add_request.assert_called_once_with(expected_dict)
+
+    def test_pool_update_unset_new_session_timeout(self):
+        self.ref_update_pool.session_persistence = data_models.UnsetType()
+        info = {'id': self.ref_update_pool.pool_id,
+                'loadbalancer_id': self.ref_update_pool.loadbalancer_id,
+                'protocol': self.ref_pool.protocol,
+                'admin_state_up': self.ref_update_pool.admin_state_up}
         expected_dict = {'type': ovn_const.REQ_TYPE_POOL_UPDATE,
                          'info': info}
         self.driver.pool_update(self.ref_pool, self.ref_update_pool)
